package com.ipu.logicflow.server.biz.logic.control;

import com.ai.ipu.basic.log.ILogger;
import com.ai.ipu.basic.log.IpuLoggerFactory;
import com.ai.ipu.data.JMap;
import com.ai.ipu.data.impl.JsonMap;
import com.alibaba.fastjson.JSONObject;
import com.ipu.logicflow.server.biz.logic.service.LogicService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * <p>desc: 逻辑服务调用的入口 </p>
 * <p>date: 2021/11/25 15:00 </p>
 *
 * @author nuosi fsofs@163.com
 * @version v1.0.0
 */
@Controller
@RequestMapping("/logic")
public class LogicController {
    private static final ILogger LOG = IpuLoggerFactory.createLogger(LogicController.class);

    @Autowired
    private LogicService logicService;

    @ResponseBody
    @RequestMapping("/executeLogic/{logicId}")
    public Object executeLogic(@PathVariable("logicId") String logicId, @RequestBody JSONObject input) throws Exception {
        System.out.println("logicId="+logicId);
        System.out.println("input="+input);
        JMap param = new JsonMap(input.toJSONString());
        Object result = logicService.execute(logicId, param);
        return result;
    }
    
    @ResponseBody
    @RequestMapping("/registerFlow")
    public Object registerFlow(@RequestBody String flowXml) throws Exception {
        System.out.println("input="+flowXml);    
        Object result = logicService.registerFlow(flowXml);
        return result;
    }
    
    @ResponseBody
    @RequestMapping("/registerModel")
    public Object registerModel(@RequestBody String modelXml) throws Exception {
        System.out.println("input="+modelXml);
        Object result = logicService.registerModel(modelXml);
        return result;
    }
    
    @ResponseBody
    @RequestMapping("/saveFlowToConfigCenter/{flowName}")
    public Object saveFlowToConfigCenter(@PathVariable("flowName") String flowName,@RequestBody String flowXml) throws Exception {
        System.out.println("input="+flowXml);    
        logicService.saveFlowToConfigCenter(flowName, flowXml);
        return "ok";
    }
    
    @ResponseBody
    @RequestMapping("/saveModelToConfigCenter/{modelName}")
    public Object saveModelToConfigCenter(@PathVariable("modelName") String modelName,@RequestBody String modelXml) throws Exception {
        System.out.println("input="+modelXml);    
        logicService.saveModelToConfigCenter(modelName, modelXml);
        return "ok";
    }

}
