package com.ipu.logicflow.server.biz.logic.service.impl;

import com.ai.ipu.basic.log.ILogger;
import com.ai.ipu.basic.log.IpuLoggerFactory;
import com.ai.ipu.data.JMap;
import com.ai.ipu.nacos.INacosService;
import com.github.pagehelper.util.StringUtil;
import com.nuosi.flow.data.BDataDefine;
import com.nuosi.flow.data.BizDataManager;
import com.nuosi.flow.logic.LogicFlowEngine;
import com.nuosi.flow.logic.LogicFlowManager;
import com.nuosi.flow.logic.model.LogicFlow;
import com.nuosi.flow.logic.model.domain.DomainModel;
import com.nuosi.flow.logic.parse.ModelToDataDefineUtil;
import com.ipu.logicflow.server.biz.logic.service.LogicService;
import com.ipu.logicflow.server.util.LogicFlowConfig;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>desc: 逻辑服务的实现 </p>
 * <p>date: 2021/12/4 1:07 </p>
 *
 * @author nuosi fsofs@163.com
 * @version v1.0.0
 */

@Service
public class LogicServiceImpl implements LogicService {
	private static final ILogger LOG = IpuLoggerFactory.createLogger(LogicServiceImpl.class);
	
	@Autowired
	private INacosService service;
	
    @Override
    public Object execute(String logicName, JMap param) throws Exception {
    	if (LogicFlowConfig.getFlowPathMap() != null && 
    			LogicFlowConfig.getFlowPathMap().containsKey(logicName))
        {
    		Object result = LogicFlowEngine.execute(logicName, param);
            return result;
        }
    	else
        	return "{\"IPU_RESULT_INFO\":\"执行异常：服务逻辑对象[" + logicName + "]不存在或未注册\",\"IPU_RESULT_CODE\":\"FLOW_NOT_EXISTS\"}";
    }

	@Override
	public String registerFlow(String flowXml) throws Exception {
		InputStream xml = null;
		String flowName = null;
		try {
			xml = new ByteArrayInputStream(flowXml.getBytes(StandardCharsets.UTF_8.name()));
			//先注册到核心流程引擎
			Object result = LogicFlowManager.registerLogicFlow(xml);
			if (result!=null)
			{
				//注册成功后再将配置缓存到本地
				flowName = ((LogicFlow)result).getId();
				LogicFlowConfig.addFlowPathMap(flowName, flowXml);
			}
			else
				flowName = null;
		}finally {
			if (xml != null)
			{
				try {
					xml.close();
				}catch (Exception e) {
					LOG.error(e.toString());
				}
				    
			}
		}
		return flowName;
	}

	@Override
	public String registerModel(String modelXml) throws Exception {
		InputStream xml = null;
		String modelName = null;
		try {
			xml = new ByteArrayInputStream(modelXml.getBytes(StandardCharsets.UTF_8.name()));
			//先注册到核心流程引擎
			DomainModel domainModel = LogicFlowManager.registerDomainModel(xml);
            BDataDefine dataDefine = ModelToDataDefineUtil.parse(domainModel.getId());
            BizDataManager.registerDto(dataDefine, true);
			
			if (domainModel!=null)
			{
				//注册成功后再将配置缓存到本地
				modelName = domainModel.getId();
				LogicFlowConfig.addModelPathMap(modelName, modelXml);
			}
			else
				modelName = null;
		}finally {
			if (xml != null)
			{
				try {
					xml.close();
				}catch (Exception e) {
					LOG.error(e.toString());
				}
				    
			}
		}
		return modelName;
	}

	@Override
	public void saveFlowToConfigCenter(String flowName, String flowXml) throws Exception {
		String strConfigInfo = service.pullFromServer(LogicFlowConfig.FLOW_LOGIC, null, 0);
		StringBuffer newConfigInfo = new StringBuffer();
		if (!StringUtil.isEmpty(strConfigInfo))
		    newConfigInfo.append(strConfigInfo).append("\n");
		newConfigInfo.append(flowName).append("==").append(LogicFlowConfig.replaceBlank(flowXml));
		service.pushConfigToServer(LogicFlowConfig.FLOW_LOGIC, "DEFAULT_GROUP", newConfigInfo.toString());
	}

	@Override
	public void saveModelToConfigCenter(String modelName, String modelXml) throws Exception {
		String strConfigInfo = service.pullFromServer(LogicFlowConfig.FLOW_LOGIC, null, 0);
		StringBuffer newConfigInfo = new StringBuffer();
		if (!StringUtil.isEmpty(strConfigInfo))
		    newConfigInfo.append(strConfigInfo).append("\n");
		newConfigInfo.append(modelName).append("==").append(LogicFlowConfig.replaceBlank(modelXml));
		service.pushConfigToServer(LogicFlowConfig.FLOW_MODEL, "DEFAULT_GROUP", newConfigInfo.toString());
	}

	@Override
	public void unregisterFlow(String flowId) throws Exception {
		//缺少注销方法，因此在执行逻辑处增加判断条件。
		LogicFlowConfig.removeFlowPathMap(flowId);
	}

	@Override
	public void unregisterModel(String modelId) throws Exception {
		BizDataManager.unregisterDto(modelId);
		LogicFlowConfig.removeModelPathMap(modelId);	
	}
}
