package com.ipu.logicflow.server.util;

import com.ai.ipu.basic.log.ILogger;
import com.ai.ipu.basic.log.IpuLoggerFactory;
import com.ai.ipu.basic.string.StringUtil;
import com.ai.ipu.restful.spring.SpringBeanUtil;
import com.ipu.logicflow.server.biz.logic.service.LogicService;
import com.nuosi.flow.util.LogicFlowUtil;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Optional;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * <p>
 * desc: LogicFlow配置类
 * </p>
 * <p>
 * date: 2021/12/30 23:58
 * </p>
 *
 * @author nuosi fsofs@163.com
 * @version v1.0.0
 */
public class LogicFlowConfig {
	private static final ILogger LOG = IpuLoggerFactory.createLogger(LogicFlowConfig.class);
	public static final String FLOW_LOGIC = "flowLogic.xml";
	public static final String FLOW_MODEL = "flowModel.xml";

	private static Map<String, String> modelPathMap = new HashMap<String, String>();
	private static Map<String, String> flowPathMap = new HashMap<String, String>();
	/*  保存配置中心配置列表，用于动态维护配置中心的配置  */
	private static Map<String/* 取值：model、flow */, Map<String/* modelPath or flowPath */, Long/* 时间戳，单位为毫秒 */>> configCenterMap = new HashMap<String, Map<String, Long>>();

	public static void init() {
		initModel();
		initFlow();
	}

	public static void initModel() {
		modelPathMap.put("sec_user", "flow/user/model/sec_user.xml");
		modelPathMap.put("sec_organize", "flow/org/model/sec_organize.xml");
		modelPathMap.put("sec_org_user_rel", "flow/org/model/sec_org_user_rel.xml");
		modelPathMap.put("sec_menu", "flow/menu/model/sec_menu.xml");
		modelPathMap.put("sec_priv_entity", "flow/menu/model/sec_priv_entity.xml");
		modelPathMap.put("sec_role_grant", "flow/role/model/sec_role_grant.xml");
		modelPathMap.put("sec_user_rel", "flow/role/model/sec_user_rel.xml");
		modelPathMap.put("sec_role", "flow/role/model/sec_role.xml");
		Iterator<String> it = modelPathMap.values().iterator();
		while (it.hasNext()) {
			LogicFlowUtil.loadLogicModel(it.next());

		}
	}

	public static void initFlow() {
		flowPathMap.put("user_insert", "flow/user/user_insert.xml");
		flowPathMap.put("user_select", "flow/user/user_select.xml");
		flowPathMap.put("user_select_by_name", "flow/user/user_select_by_name.xml");
		flowPathMap.put("user_select_by_cond", "flow/user/user_select_by_cond.xml");
		flowPathMap.put("user_update_by_cond", "flow/user/user_update_by_cond.xml");
		flowPathMap.put("user_update", "flow/user/user_update.xml");
		flowPathMap.put("user_disable_with_aggregate", "flow/user/user_disable_with_aggregate.xml");

		
		flowPathMap.put("organize_select", "flow/org/organize_select.xml");
		flowPathMap.put("organize_select_by_name", "flow/org/organize_select_by_name.xml");
		flowPathMap.put("organize_insert", "flow/org/organize_insert.xml");
		flowPathMap.put("organize_update", "flow/org/organize_update.xml");
		flowPathMap.put("dept_org_user_select", "flow/org/dept_org_user_select.xml");
		flowPathMap.put("org_user_rel_combine_select", "flow/org/org_user_rel_combine_select.xml");
		flowPathMap.put("org_user_rel_delete_by_cond", "flow/org/org_user_rel_delete_by_cond.xml");
		flowPathMap.put("org_user_rel_delete", "flow/org/org_user_rel_delete.xml");
		flowPathMap.put("org_user_rel_insert", "flow/org/org_user_rel_insert.xml");
		flowPathMap.put("org_user_rel_select_by_cond", "flow/org/org_user_rel_select_by_cond.xml");
		flowPathMap.put("org_user_rel_select_by_org_id", "flow/org/org_user_rel_select_by_org_id.xml");
		flowPathMap.put("org_user_rel_select", "flow/org/org_user_rel_select.xml");
		
		flowPathMap.put("aggregate_menu_select", "flow/menu/aggregate_menu_select.xml");
		flowPathMap.put("aggregate_priv_entity_select", "flow/menu/aggregate_priv_entity_select.xml");
		flowPathMap.put("menu_delete_by_cond", "flow/menu/menu_delete_by_cond.xml");
		flowPathMap.put("menu_insert", "flow/menu/menu_insert.xml");
		flowPathMap.put("menu_select", "flow/menu/menu_select.xml");
		flowPathMap.put("menu_update_by_cond", "flow/menu/menu_update_by_cond.xml");
		flowPathMap.put("priv_entity_delete", "flow/menu/priv_entity_delete.xml");
		flowPathMap.put("priv_entity_insert", "flow/menu/priv_entity_insert.xml");
		flowPathMap.put("priv_entity_update_by_cond", "flow/menu/priv_entity_update_by_cond.xml");
		flowPathMap.put("priv_entity_update_menu_by_cond", "flow/menu/priv_entity_update_menu_by_cond.xml");
		
		flowPathMap.put("role_delete", "flow/role/role_delete.xml");
		flowPathMap.put("role_grant_delete", "flow/role/role_grant_delete.xml");
		flowPathMap.put("role_grant_insert", "flow/role/role_grant_insert.xml");
		flowPathMap.put("role_grant_select", "flow/role/role_grant_select.xml");
		flowPathMap.put("role_grant_update_by_cond", "flow/role/role_grant_update_by_cond.xml");
		flowPathMap.put("role_insert", "flow/role/role_insert.xml");
		flowPathMap.put("role_select", "flow/role/role_select.xml");
		flowPathMap.put("role_update_by_cond", "flow/role/role_update_by_cond.xml");
		flowPathMap.put("role_user_rel_delete_by_cond", "flow/role/role_user_rel_delete_by_cond.xml");
		flowPathMap.put("role_user_rel_insert", "flow/role/role_user_rel_insert.xml");
		flowPathMap.put("role_user_rel_select_by_cond", "flow/role/role_user_rel_select_by_cond.xml");
		
		Iterator<String> it = flowPathMap.values().iterator();
		while (it.hasNext()) {
			LogicFlowUtil.loadLogicFlow(it.next());
		}
	}

	public static Map<String, String> getModelPathMap() {
		return (Map<String, String>) ((HashMap<String, String>) modelPathMap).clone();
	}

	public static Map<String, String> getFlowPathMap() {
		return (Map<String, String>) ((HashMap<String, String>) flowPathMap).clone();
	}

	public static void addModelPathMap(String modelName, String modelXml) {
		modelPathMap.put(modelName, modelXml);
	}

	public static void addFlowPathMap(String flowName, String flowXml) {
		flowPathMap.put(flowName, flowXml);
	}
	
	public static void removeModelPathMap(String modelName) {
		modelPathMap.remove(modelName);
	}

	public static void removeFlowPathMap(String flowName) {
		flowPathMap.remove(flowName);
	}

	public static String replaceBlank(String str) {
		String dest = "";
		if (str != null) {
			Pattern p = Pattern.compile("\\\r|\n");
			Matcher m = p.matcher(str);
			dest = m.replaceAll("");
		}
		return dest;
	}
	
	//只有配置中心代码才会调用
	public static void registerLogicFlow(String flowConfig) throws Exception {
		Map<String, Long> flowMap = getConfigCenterMap(FLOW_LOGIC);
		Map<String, Long> flowCloneMap = (Map<String, Long>) ((HashMap<String, Long>) flowMap).clone();
		if (!StringUtil.isEmpty(flowConfig)) {
			String[] configs = flowConfig.split("\n");
			int i=0;
			for (;i<configs.length;i++) {
				String[] config = configs[i].split("==");
				if (!LogicFlowConfig.getFlowPathMap().containsKey(config[0]))
				{
					LogicService logicService = SpringBeanUtil.getBean(LogicService.class);
					logicService.registerFlow(config[1]);
					addConfigCenterMap(FLOW_LOGIC, config[0]);
					LOG.debug("添加Flow配置成功：" + config[1]);
				}
				flowCloneMap.remove(config[0]);
			}	
		}

		//需要清除配置中心没有的flow数据
		try {
			LogicService logicService = SpringBeanUtil.getBean(LogicService.class);
			flowCloneMap.forEach((k, v) -> {
				flowMap.remove(k);
				try {
					logicService.unregisterFlow(k);
				} catch (Exception e) {
					e.printStackTrace();
				}
				});
		}finally {
			flowCloneMap.clear();
		}

	}
	
	//只有配置中心代码才会调用
	public static void registerLogicModel(String modelConfig) throws Exception {
		Map<String, Long> modelMap = getConfigCenterMap(FLOW_MODEL);
		Map<String, Long> modelCloneMap = (Map<String, Long>) ((HashMap<String, Long>) modelMap).clone();
		if (!StringUtil.isEmpty(modelConfig)) {
			String[] configs = modelConfig.split("\n");
			
			int i=0;
			for (;i<configs.length;i++) {
				String[] config = configs[i].split("==");
				if (!LogicFlowConfig.getModelPathMap().containsKey(config[0]))
				{
					LogicService logicService = SpringBeanUtil.getBean(LogicService.class);
					logicService.registerModel(config[1]);
					addConfigCenterMap(FLOW_MODEL, config[0]);
					LOG.debug("添加Model配置成功：" + config[1]);
				}
				modelCloneMap.remove(config[0]);
			}	
		}
		
		//需要清除配置中心没有的model数据
		try {
			LogicService logicService = SpringBeanUtil.getBean(LogicService.class);
			modelCloneMap.forEach((k, v) -> {
				modelMap.remove(k);
				try {
					logicService.unregisterModel(k);
				} catch (Exception e) {
					e.printStackTrace();
				}
				});
		}finally {			
			modelCloneMap.clear();
		}
		
	}
	
	private static HashMap<String, Long> getConfigCenterMap(String configType) {
		if (!configCenterMap.containsKey(configType))
			configCenterMap.put(configType, new HashMap<String, Long>());
		return (HashMap<String, Long>) configCenterMap.get(configType);
	}
	
	private static void addConfigCenterMap(String configType, String configId) {
		Map<String, Long> configsMap = getConfigCenterMap(configType);
		if (getConfigIdOptional(configType, configId).isPresent())
			configsMap.put(configId, getTimeStamp());
		else
		{
			Map<String, Long> value = new HashMap<String, Long>();
			value.put(configId, getTimeStamp());
			configCenterMap.put(configType, value);
		}
	}
	
	private static boolean removeConfigCenterMap(String configType, String configId) {
		Map<String, Long> configsMap = getConfigCenterMap(configType);
		if (getConfigIdOptional(configType, configId).isPresent())
			return configsMap.remove(configId) == null?true:false;
		return false;
	}
	
	private static boolean existConfigCenterMap(String configType, String configId) {
		return getConfigIdOptional(configType, configId).isPresent();
	}
	
	private static Optional<Object> getConfigIdOptional(String configType, String configId) {
		Map<String, Long> configsMap = getConfigCenterMap(configType);
		Optional<Map<String, Long>> configOptional = Optional.ofNullable(configsMap);
		return configOptional.map(configMap ->Optional.ofNullable(configMap.get(configId)));
	}
	
	private static long getTimeStamp() {
		return System.currentTimeMillis();
	}
}
