package com.ipu.logicflow.server;

import com.ai.ipu.data.JMap;
import com.ai.ipu.data.impl.JsonMap;
import com.alibaba.fastjson.JSONObject;
import com.nuosi.flow.logic.LogicFlowEngine;
import com.nuosi.flow.logic.inject.initial.InitialMethod;
import com.nuosi.flow.util.LogicFlowUtil;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.io.IOException;

/**
 * <p>desc: 菜单对象逻辑的测试 </p>
 * <p>date: 2022/3/18 22:10 </p>
 *
 * @author nuosi fsofs@163.com
 * @version v1.0.0
 */
public class MenuTest {

    @Test
    public void testInsertMenu(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            JMap myMenu = createMenu();
            param.put("menu", new JSONObject(myMenu));
            result = LogicFlowEngine.execute("menu_insert", param);
            System.out.println("执行结果：" + result);
            Assert.assertEquals("新增菜单信息成功!", result.getInt("insert_num"), 1);
            
            JSONObject menu = new JSONObject();
            menu.put("menu_id", myMenu.get("menu_id"));
            param.put("menu", menu);
            result = LogicFlowEngine.execute("menu_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertNotNull(result.get("menu_info"));
            
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testDeleteMenuByCond(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            param.put("menu_id", 613901);
            result = LogicFlowEngine.execute("menu_delete_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testSelectMenu() {
        JMap param = new JsonMap();
        JSONObject menu = new JSONObject();
        menu.put("menu_id", "613901");
        param.put("menu", menu);
        try{
            JMap result = LogicFlowEngine.execute("menu_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testSelectAggregateMenu() {
        JMap param = new JsonMap();
        param.put("role_id", 284247);
        try{
            JMap result = LogicFlowEngine.execute("aggregate_menu_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testUpdateMenuByCond(){
        String menu_id = "613901";
        JSONObject menu_cond = new JSONObject();
        menu_cond.put("menu_id", menu_id);

        JSONObject menu = new JSONObject();
        menu.put("menu_id", menu_id);
        menu.put("MENU_NAME", "嘉信立恒管理员");
        

        JMap param = new JsonMap();
        param.put("menu_cond", menu_cond);
        param.put("menu", menu);
        try{
            JMap result = LogicFlowEngine.execute("menu_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Before
    public void before() throws IOException {
        String[] models = {
                "flow/menu/model/sec_menu.xml",
                "flow/role/model/sec_role.xml",
                "flow/menu/model/sec_priv_entity.xml"
        };
        LogicFlowUtil.loadLogicModels(models);

        String[] flows = {
                "flow/menu/menu_insert.xml",
                "flow/menu/menu_select.xml",
                "flow/menu/aggregate_menu_select.xml",
                "flow/menu/menu_update_by_cond.xml",
                "flow/menu/menu_delete_by_cond.xml"
        };

        LogicFlowUtil.loadLogicFlows(flows);
    }

    private JMap createMenu() throws Exception {
        String menu_id = String.valueOf(System.currentTimeMillis()).substring(7);
        JMap menuParam = new JsonMap();
        menuParam.put("menu_id", menu_id);
        menuParam.put("parent_menu_id", "1");
        menuParam.put("menu_type", "2");
        menuParam.put("menu_name", "系统管理");
        menuParam.put("menu_title", "1");
        menuParam.put("level", "1");
        menuParam.put("menu_sort", "1");
        menuParam.put("menu_component", "md-home");
        menuParam.put("menu_icon", "/sys");
//        menuParam.put("link_url", null);
        menuParam.put("iframe_flag", "0");
        menuParam.put("hidden_flag", "1");
        menuParam.put("data_status", "1");
        menuParam.put("create_date", new InitialMethod().getDatetime());
        menuParam.put("done_date", new InitialMethod().getDatetime());
        menuParam.put("op_id", "1");
        return menuParam;
    }
}
