package com.ipu.logicflow.server;

import com.ai.ipu.data.JMap;
import com.ai.ipu.data.impl.JsonMap;
import com.alibaba.fastjson.JSONObject;
import com.nuosi.flow.logic.LogicFlowEngine;
import com.nuosi.flow.logic.inject.initial.InitialMethod;
import com.nuosi.flow.util.LogicFlowUtil;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.io.IOException;

/**
 * <p>desc: 用户组织信息管理逻辑的测试 </p>
 * <p>date: 2022/3/30 13:44 </p>
 *
 * @author weihf@asiainfo.com
 * @version v1.0.0
 */
public class OrgUserRelTest {

    @Test
    public void testInsertOrgUserRel(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            param.put("org_user_rel", new JSONObject(createOrgUserRel()));
            result = LogicFlowEngine.execute("org_user_rel_insert", param);
            System.out.println("执行结果：" + result);
            Assert.assertEquals("新增组织下人员信息失败!", result.getInt("insert_num"), 1);
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testSelectOrgUserRel() {
        JMap param = new JsonMap();
        JSONObject org_user_rel = new JSONObject();
        org_user_rel.put("ORG_USER_REL_ID", "1");
        param.put("org_user_rel", org_user_rel);
        try{
            JMap result = LogicFlowEngine.execute("org_user_rel_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testSelectOrgUserRelByUserId() {
        JMap param = new JsonMap();
        param.put("organize_id", 33);
        param.put("user_id", 308075);

        try{
            JMap result = LogicFlowEngine.execute("org_user_rel_select_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testSelectUserOrganizeByUserId() {
        JMap param = new JsonMap();
        param.put("organize_id", 33);
        param.put("user_id", 308075);

        try{
            JMap result = LogicFlowEngine.execute("org_user_rel_combine_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testSelectUserOrganizeByOrgId() {
        JMap param = new JsonMap();
        param.put("organize_id", 33);

        try{
            JMap result = LogicFlowEngine.execute("org_user_rel_select_by_org_id", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testDeleteOrgUserRelByUserId(){
    	JMap param = new JsonMap();
        param.put("organize_id", 33);
        param.put("user_id", 308075);
        JMap result = null;
        try {
            
            result = LogicFlowEngine.execute("org_user_rel_delete_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testDeleteOrgUserRel(){
    	int org_user_rel_id = 3;
        JSONObject org_user_rel_cond = new JSONObject();
        org_user_rel_cond.put("org_user_rel_id", org_user_rel_id);
        org_user_rel_cond.put("organize_id", 33);
        JMap param = new JsonMap();
        param.put("org_user_rel", org_user_rel_cond);
        JMap result = null;
        try {
            //错误信息：执行异常：服务逻辑对象[org_user_rel_delete]节点[deleteOrgUserRel]执行异常，异常信息：[DB]域[delete]函数执行异常(空信息)
            result = LogicFlowEngine.execute("org_user_rel_delete", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        } catch (Exception e) {
        	e.printStackTrace();
            System.out.println("错误信息：" + e.toString());
            Assert.assertTrue(false);
        }
    }
    
    @Before
    public void before() throws IOException {
        String[] models = {
                "flow/org/model/sec_org_user_rel.xml",
                "flow/user/model/sec_user.xml",
                "flow/org/model/sec_organize.xml"
        };
        LogicFlowUtil.loadLogicModels(models);

        String[] flows = {
                "flow/org/org_user_rel_insert.xml",
                "flow/org/org_user_rel_delete.xml",
                "flow/org/org_user_rel_delete_by_cond.xml",
                "flow/org/org_user_rel_select.xml",
                "flow/org/org_user_rel_select_by_cond.xml",
                "flow/org/org_user_rel_combine_select.xml",
                "flow/org/org_user_rel_select_by_org_id.xml",
                "flow/user/user_select_by_id.xml",
                "flow/org/organize_select.xml"
        };

        LogicFlowUtil.loadLogicFlows(flows);
    }

    private JMap createOrgUserRel() throws Exception {
        //String org_user_rel_id = String.valueOf(System.currentTimeMillis()).substring(7);
        JMap menuParam = new JsonMap();
        //[ORG_USER_REL_ID]字段为自增字段
        //menuParam.put("ORG_USER_REL_ID", org_user_rel_id);
        menuParam.put("ORGANIZE_ID", "33");
        menuParam.put("USER_ID", "308075");
        menuParam.put("DATA_STATUS", "1");      
        menuParam.put("CREATE_DATE", new InitialMethod().getDatetime());
        menuParam.put("CREATE_OP_ID", "1");
        menuParam.put("DONE_DATE", new InitialMethod().getDatetime());
        menuParam.put("OP_ID", "1");
        return menuParam;
    }
}
