package com.ipu.logicflow.server;

import com.ai.ipu.data.JMap;
import com.ai.ipu.data.impl.JsonMap;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.nuosi.flow.logic.LogicFlowEngine;
import com.nuosi.flow.logic.inject.initial.InitialMethod;
import com.nuosi.flow.util.LogicFlowUtil;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.io.IOException;
import java.util.List;

/**
 * <p>desc: 组织对象逻辑的测试 </p>
 * <p>date: 2022/3/13 10:53 </p>
 *
 * @author nuosi fsofs@163.com
 * @version v1.0.0
 */
public class OrganizeTest {

    @Test
    public void testInsertOrganize(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            param.put("organize", new JSONObject(createOrganize()));
            result = LogicFlowEngine.execute("organize_insert", param);
            System.out.println("执行结果：" + result);
            Assert.assertEquals("新增组织信息失败!", result.getInt("insert_num"), 1);
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testSelectOrganize() {
        JMap param = new JsonMap();
        JSONObject organize = new JSONObject();
        organize.put("organize_id", "33");
        param.put("organize", organize);
        try{
            JMap result = LogicFlowEngine.execute("organize_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testSelectOrganizeByName() {
        JMap param = new JsonMap();
        param.put("organize_name", "亚信");
        
        try{
            JMap result = LogicFlowEngine.execute("organize_select_by_name", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue("查询组织列表失败!", ((List)result.get("organize_list")).size()>=1);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testSelectDeptOrganizeById() {
        JMap param = new JsonMap();
        param.put("organize_id", "33");
        
        try{
            JMap result = LogicFlowEngine.execute("dept_org_user_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testUpdateOrganizeById(){
    	JSONObject organize_cond = new JSONObject();
    	organize_cond.put("organize_id", "33");        

        JMap param = new JsonMap();
        try{
        	JSONObject organize = new JSONObject();
            
            organize.put("dept_full_id", "2");
            organize.put("dept_leader", 308075);
            organize.put("op_id", "1");
            
            param.put("organize", organize);
            param.put("organize_cond", organize_cond);
            
            JMap result = LogicFlowEngine.execute("organize_update", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Before
    public void before() throws IOException {
        String[] models = {
                "flow/org/model/sec_organize.xml"
        };
        LogicFlowUtil.loadLogicModels(models);

        String[] flows = {
                "flow/org/organize_insert.xml",
                "flow/org/organize_select.xml",
                "flow/org/organize_select_by_name.xml",
                "flow/org/dept_org_user_select.xml",
                "flow/org/organize_update.xml"
        };

        LogicFlowUtil.loadLogicFlows(flows);
    }

    private JMap createOrganize() throws Exception {
        String organize_id = String.valueOf(System.currentTimeMillis()).substring(7);
        JMap organizeParam = new JsonMap();
        organizeParam.put("organize_id", organize_id);
        organizeParam.put("organize_type", "0");
        organizeParam.put("organize_name", "亚信科技有限责任公司");
        organizeParam.put("parent_organize_id", "0");
        organizeParam.put("short_name", "亚信科技");
        organizeParam.put("english_name", "asiainfo");
        organizeParam.put("dept_full_id", "1");
        organizeParam.put("dept_full_name", "亚信科技");
        organizeParam.put("level", 1);
        organizeParam.put("dept_leader", 1);
        organizeParam.put("org_level", "1");
        organizeParam.put("remark", "NULL");
        organizeParam.put("data_status", "1");
        organizeParam.put("create_date", "2022-1-10 16:09:12");
        organizeParam.put("create_op_id", "1");
        organizeParam.put("done_date", new InitialMethod().getDatetime());
        organizeParam.put("op_id", new InitialMethod().getDatetime());
        return organizeParam;
    }
}
