package com.ipu.logicflow.server;

import com.ai.ipu.data.JMap;
import com.ai.ipu.data.impl.JsonMap;
import com.alibaba.fastjson.JSONObject;
import com.nuosi.flow.logic.LogicFlowEngine;
import com.nuosi.flow.logic.inject.initial.InitialMethod;
import com.nuosi.flow.util.LogicFlowUtil;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.io.IOException;

/**
 * <p>desc: 角色关联菜单对象逻辑的测试 </p>
 * <p>date: 2022/3/18 23:19 </p>
 *
 * @author nuosi fsofs@163.com
 * @version v1.0.0
 */
public class PrivEntityTest {

    @Test
    public void testInsertPrivEntity(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            param.put("priv_entity", new JSONObject(createPrivEntity()));
            result = LogicFlowEngine.execute("priv_entity_insert", param);
            System.out.println("执行结果：" + result);
            Assert.assertEquals("新增角色关联菜单信息失败!", result.getInt("insert_num"), 1);
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testSelectAggregatePrivEntity() {
        JMap param = new JsonMap();
        param.put("priv_ent_id", 2);
        try{
            JMap result = LogicFlowEngine.execute("aggregate_priv_entity_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testUpdatePrivEntityByCond(){
        String priv_ent_id = "2";
        JSONObject priv_entity_cond = new JSONObject();
        priv_entity_cond.put("priv_ent_id", priv_ent_id);

        JSONObject priv_entity = new JSONObject();
        priv_entity.put("priv_ent_code", "1");
        priv_entity.put("priv_ent_name", "管理员菜单");

        JMap param = new JsonMap();
        param.put("priv_entity_cond", priv_entity_cond);
        param.put("priv_entity", priv_entity);
        try{
            JMap result = LogicFlowEngine.execute("priv_entity_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testUpdatePrivEntityMenuByCond(){
        String priv_ent_id = "2";

        JMap param = new JsonMap();
        param.put("priv_ent_id", priv_ent_id);
        param.put("busi_obj_id", 309238);
        try{
            JMap result = LogicFlowEngine.execute("priv_entity_update_menu_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testDeletePrivEntity() {
        JMap param = new JsonMap();
        param.put("priv_ent_id", 1);
        try{
            JMap result = LogicFlowEngine.execute("priv_entity_delete", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Before
    public void before() throws IOException {
        String[] models = {
                "flow/menu/model/sec_priv_entity.xml",
                "flow/menu/model/sec_menu.xml"
        };
        LogicFlowUtil.loadLogicModels(models);

        String[] flows = {
                "flow/menu/priv_entity_insert.xml",
                "flow/menu/aggregate_priv_entity_select.xml",
                "flow/menu/priv_entity_update_by_cond.xml",
                "flow/menu/priv_entity_update_menu_by_cond.xml",
                "flow/menu/priv_entity_delete.xml"
        };

        LogicFlowUtil.loadLogicFlows(flows);
    }

    private JMap createPrivEntity() throws Exception {
        String priv_ent_id = String.valueOf(System.currentTimeMillis()).substring(7);
        JMap param = new JsonMap();
        param.put("priv_ent_id", priv_ent_id);
        param.put("priv_ent_name", "角色关联菜单范例");
        param.put("busi_obj_id", 414544);
        param.put("busi_obj_type", "1");
        param.put("data_status", "1");
        param.put("create_date", new InitialMethod().getDatetime());
        param.put("create_op_id", "1");
        param.put("done_date", new InitialMethod().getDatetime());
        param.put("op_id", "1");
        return param;
    }
}
