package com.ipu.logicflow.server;

import com.ai.ipu.data.JMap;
import com.ai.ipu.data.impl.JsonMap;
import com.alibaba.fastjson.JSONObject;
import com.nuosi.flow.logic.LogicFlowEngine;
import com.nuosi.flow.logic.inject.initial.InitialMethod;
import com.nuosi.flow.util.LogicFlowUtil;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.io.IOException;

/**
 * <p>desc: 角色授权对象逻辑的测试 </p>
 * <p>date: 2022/3/18 23:03 </p>
 *
 * @author nuosi fsofs@163.com
 * @version v1.0.0
 */
public class RoleGrantTest {

    @Test
    public void testInsertRoleGrant(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            param.put("role_grant", new JSONObject(createRoleGrant()));
            result = LogicFlowEngine.execute("role_grant_insert", param);
            System.out.println("执行结果：" + result);
            Assert.assertEquals("新增角色授权信息失败!", result.getInt("insert_num"), 1);
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testDeleteRoleGrant(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            param.put("role_grant_id", 1);
            result = LogicFlowEngine.execute("role_grant_delete", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testUpdateRoleGrantByCond(){
        String role_grant_id = "2";
        JSONObject role_grant_cond = new JSONObject();
        role_grant_cond.put("role_grant_id", role_grant_id);

        JSONObject role_grant = new JSONObject();
        role_grant.put("role_id", 284247);
        role_grant.put("priv_ent_id", 2);

        JMap param = new JsonMap();
        param.put("role_grant_cond", role_grant_cond);
        param.put("role_grant", role_grant);
        try{
            JMap result = LogicFlowEngine.execute("role_grant_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testSelectRoleGrant() {
        JMap param = new JsonMap();
        JSONObject role_grant = new JSONObject();
        role_grant.put("role_grant_id", 2);
        param.put("role_grant", role_grant);
        try{
        	
            JMap result = LogicFlowEngine.execute("role_grant_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertNotNull(result.get("role_grant_info"));
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Before
    public void before() throws IOException {
        String[] models = {
                "flow/role/model/sec_role_grant.xml"
        };
        LogicFlowUtil.loadLogicModels(models);

        String[] flows = {
                "flow/role/role_grant_insert.xml",
                "flow/role/role_grant_select.xml",
                "flow/role/role_grant_update_by_cond.xml",
                "flow/role/role_grant_delete.xml"
        };

        LogicFlowUtil.loadLogicFlows(flows);
    }

    private JMap createRoleGrant() throws Exception {
        String role_grant_id = String.valueOf(System.currentTimeMillis()).substring(7);
        JMap menuParam = new JsonMap();
        menuParam.put("role_grant_id", role_grant_id);
        menuParam.put("role_id", 284247);
        menuParam.put("priv_ent_id", 414544);
        menuParam.put("valid_date", new InitialMethod().getDatetime());
        menuParam.put("data_status", "1");
        menuParam.put("create_date", new InitialMethod().getDatetime());
        menuParam.put("done_date", new InitialMethod().getDatetime());
        menuParam.put("op_id", "1");
        return menuParam;
    }
}
