package com.ipu.logicflow.server;

import com.ai.ipu.data.JMap;
import com.ai.ipu.data.impl.JsonMap;
import com.alibaba.fastjson.JSONObject;
import com.nuosi.flow.logic.LogicFlowEngine;
import com.nuosi.flow.logic.inject.initial.InitialMethod;
import com.nuosi.flow.util.LogicFlowUtil;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.io.IOException;

/**
 * <p>desc: 角色对象逻辑的测试 </p>
 * <p>date: 2022/6/20 9:10 </p>

 */
public class RoleTest {

    @Test
    public void testInsertRole(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            JMap myRole = createRole();
            param.put("role", new JSONObject(myRole));
            result = LogicFlowEngine.execute("role_insert", param);
            System.out.println("执行结果：" + result);
            
            JSONObject role = new JSONObject();
            role.put("role_id", myRole.get("role_id"));
            param.put("role", role);
            result = LogicFlowEngine.execute("role_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertNotNull(result.get("role_info"));
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testDeleteRole(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            param.put("role_id", 284247);
            result = LogicFlowEngine.execute("role_delete", param);
            System.out.println("执行结果：" + result);
            Assert.assertEquals("删除角色信息失败!", result.getInt("role_delete"), 1);
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testSelectRole() {
        JMap param = new JsonMap();
        JSONObject role = new JSONObject();
        role.put("role_id", "284247");
        param.put("role", role);
        try{
        	
            JMap result = LogicFlowEngine.execute("role_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertNotNull(result.get("role_info"));
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testUpdateRoleByCond(){
        String role_id = "284247";
        JSONObject role_cond = new JSONObject();
        role_cond.put("role_id", role_id);

        JSONObject role = new JSONObject();
        role.put("ROLE_NAME", "嘉信立恒管理员");
        

        JMap param = new JsonMap();
        param.put("role_cond", role_cond);
        param.put("role", role);
        try{
            JMap result = LogicFlowEngine.execute("role_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testEnableRole(){
        String role_id = "284247";
        JSONObject role_cond = new JSONObject();
        role_cond.put("role_id", role_id);

        JSONObject role = new JSONObject();
        role.put("data_status", "1");
        

        JMap param = new JsonMap();
        param.put("role_cond", role_cond);
        param.put("role", role);
        try{
            JMap result = LogicFlowEngine.execute("role_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testDisableRole(){
        String role_id = "284247";
        JSONObject role_cond = new JSONObject();
        role_cond.put("role_id", role_id);

        JSONObject role = new JSONObject();
        role.put("data_status", "0");
        

        JMap param = new JsonMap();
        param.put("role_cond", role_cond);
        param.put("role", role);
        try{
            JMap result = LogicFlowEngine.execute("role_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Before
    public void before() throws IOException {
        String[] models = {
                "flow/role/model/sec_role.xml"

        };
        LogicFlowUtil.loadLogicModels(models);

        String[] flows = {
                "flow/role/role_insert.xml",
                "flow/role/role_select.xml",
                "flow/role/role_update_by_cond.xml",
                "flow/role/role_delete.xml"
        };

        LogicFlowUtil.loadLogicFlows(flows);
    }

    private JMap createRole() throws Exception {
        String role_id = String.valueOf(System.currentTimeMillis()).substring(7);
        JMap roleParam = new JsonMap();
        roleParam.put("role_id", role_id);
        roleParam.put("job_id", "1");
        roleParam.put("role_type", "2");
        roleParam.put("role_name", "系统管理");
        roleParam.put("role_level", "1");
        roleParam.put("data_status", "1");
        roleParam.put("create_date", new InitialMethod().getDatetime());
        roleParam.put("done_date", new InitialMethod().getDatetime());
        roleParam.put("op_id", "1");
        return roleParam;
    }
}
