package com.ipu.logicflow.server;

import com.ai.ipu.data.JMap;
import com.ai.ipu.data.impl.JsonMap;
import com.alibaba.fastjson.JSONObject;
import com.nuosi.flow.logic.LogicFlowEngine;
import com.nuosi.flow.logic.inject.initial.InitialMethod;
import com.nuosi.flow.util.LogicFlowUtil;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.io.IOException;
import java.util.List;

/**
 * <p>desc: 用户对象逻辑的测试 </p>
 * <p>date: 2022/1/18 19:43 </p>
 *
 * @author nuosi fsofs@163.com
 * @version v1.0.0
 */
public class UserTest {

    @Test
    public void testInsertUser(){
        JMap result = null;
        try {
            JMap param = new JsonMap();
            param.put("user", new JSONObject(createUser()));
            result = LogicFlowEngine.execute("user_insert", param);
            System.out.println("执行结果：" + result);
            Assert.assertEquals("新增用户信息失败!", result.getInt("insert_num"), 1);
        } catch (Exception e) {
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testSelectUser() {
        JMap param = new JsonMap();
        JSONObject user = new JSONObject();
        user.put("user_id", "308075");
        param.put("user", user);
        try{
            JMap result = LogicFlowEngine.execute("user_select", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testSelectUserByCond() {
        JMap param = new JsonMap();
        JSONObject user = new JSONObject();
//        user.put("user_id", "308075");
        user.put("data_status", "0");
        param.put("user_cond", user);
        try{
            JMap result = LogicFlowEngine.execute("user_select_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);
        }catch (Exception e){
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testSelectUserByName() throws Exception {
        JMap param = new JsonMap();
        param.put("nick_name", "嘉信立恒");

        try{
            JMap result = LogicFlowEngine.execute("user_select_by_name", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue("查询用户列表失败!", ((List)result.get("user_list")).size()>=1);
        }catch (Exception e){
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testDisableUser(){
        String user_id = "308075";
        JSONObject user_cond = new JSONObject();
        user_cond.put("user_id", user_id);

        JSONObject user = new JSONObject();
        user.put("enabled_flag", "0");
        user.put("done_date", new InitialMethod().getDatetime());
        user.put("op_id", "1");

        JMap param = new JsonMap();
        param.put("user_cond", user_cond);
        param.put("user", user);
        try{
            JMap result = LogicFlowEngine.execute("user_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

            // 还原数据
            user.put("enabled_flag", "1");
            user.put("op_id", user_id);
            param.put("user", user);
            LogicFlowEngine.execute("user_update_by_cond", param);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testDisableUserWithAggregate(){
        String user_id = "308075";
        JMap param = new JsonMap();
        param.put("user_id", user_id);
        try{
            JMap result = LogicFlowEngine.execute("user_disable_with_aggregate", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

            // 还原数据
            JSONObject user = new JSONObject();
            user.put("enabled_flag", "1");
            user.put("op_id", user_id);
            param.put("user", user);

            JSONObject user_cond = new JSONObject();
            user_cond.put("user_id", user_id);
            param.put("user_cond", user_cond);

            LogicFlowEngine.execute("user_update_by_cond", param);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testEnableUser(){
        String user_id = "308075";
        JSONObject user_cond = new JSONObject();
        user_cond.put("user_id", user_id);

        JSONObject user = new JSONObject();
        user.put("enabled_flag", "1");
        user.put("done_date", new InitialMethod().getDatetime());
        user.put("op_id", "1");

        JMap param = new JsonMap();
        param.put("user_cond", user_cond);
        param.put("user", user);
        try{
            JMap result = LogicFlowEngine.execute("user_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

            // 还原数据
            user.put("enabled_flag", "0");
            user.put("op_id", user_id);
            param.put("user", user);
            LogicFlowEngine.execute("user_update_by_cond", param);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testUpdateUserByCond(){
        String user_id = "308075";
        JSONObject user_cond = new JSONObject();
        user_cond.put("user_id", user_id);

        JSONObject user = new JSONObject();
        user.put("user_id", user_id);
        user.put("NICK_NAME", "嘉信立恒管理员");
        user.put("USER_ACCOUNT", "admin");
        user.put("GENDER", "1");
        user.put("AVATAR_NAME", "head.jpg");
        user.put("SURNAME", "刘恒");
        user.put("EMAIL", "tls@163.com");
        user.put("SEC_LEVEL", "2");
        user.put("LINK_PHONE", "18935548888");
        user.put("PASSWORD", "qawsx");       
        user.put("done_date", new InitialMethod().getDatetime());
        user.put("op_id", "1");

        JMap param = new JsonMap();
        param.put("user_cond", user_cond);
        param.put("user", user);
        try{
            JMap result = LogicFlowEngine.execute("user_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testUpdateUser(){
        String user_id = "308075";
        JSONObject user_cond = new JSONObject();
        user_cond.put("user_id", user_id);

        JSONObject user = new JSONObject();
        user.put("user_id", user_id);
        user.put("NICK_NAME", "嘉信立恒管理员");
        user.put("USER_ACCOUNT", "admin");
        user.put("GENDER", "1");
        user.put("AVATAR_NAME", "head.jpg");
        user.put("SURNAME", "刘恒");
        user.put("EMAIL", "tls@163.com");
        user.put("SEC_LEVEL", "2");
        user.put("LINK_PHONE", "18935548888");
        user.put("PASSWORD", "qawsx");       
        user.put("done_date", new InitialMethod().getDatetime());
        user.put("op_id", "1");

        JMap param = new JsonMap();
        param.put("user", user);
        try{
            JMap result = LogicFlowEngine.execute("user_update", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Test
    public void testDeleteUser(){
        String user_id = "308075";
        JSONObject user_cond = new JSONObject();
        user_cond.put("user_id", user_id);

        JSONObject user = new JSONObject();
        user.put("DATA_STATUS", "0");
        user.put("done_date", new InitialMethod().getDatetime());
        user.put("op_id", "1");

        JMap param = new JsonMap();
        param.put("user_cond", user_cond);
        param.put("user", user);
        try{
            JMap result = LogicFlowEngine.execute("user_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

            // 还原数据
            user.put("DATA_STATUS", "1");
            user.put("op_id", user_id);
            param.put("user", user);
            LogicFlowEngine.execute("user_update_by_cond", param);
        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }
    
    @Test
    public void testResetUserPasswd(){
        String user_id = "308075";
        JSONObject user_cond = new JSONObject();
        user_cond.put("user_id", user_id);

        JSONObject user = new JSONObject();       		
        user.put("PASSWORD", "qwertyu");       
        user.put("done_date", new InitialMethod().getDatetime());
        user.put("op_id", "1");

        JMap param = new JsonMap();
        param.put("user_cond", user_cond);
        param.put("user", user);
        try{
            JMap result = LogicFlowEngine.execute("user_update_by_cond", param);
            System.out.println("执行结果：" + result);
            Assert.assertTrue(true);

        }catch (Exception e){
            e.printStackTrace();
            System.out.println("错误信息：" + e.getMessage());
            Assert.assertTrue(false);
        }
    }

    @Before
    public void before() throws IOException {
        String[] models = {
                "flow/user/model/sec_user.xml"
        };
        LogicFlowUtil.loadLogicModels(models);

        String[] flows = {
                "flow/user/user_insert.xml",
                "flow/user/user_select.xml",
                "flow/user/user_select_by_cond.xml",
                "flow/user/user_select_by_name.xml",
                "flow/user/user_update_by_cond.xml",
                "flow/user/user_update.xml",
                "flow/user/user_disable_with_aggregate.xml"
        };

        LogicFlowUtil.loadLogicFlows(flows);
    }

    private JMap createUser() throws Exception {
        String user_id = String.valueOf(System.currentTimeMillis()).substring(7);
        JMap userParam = new JsonMap();
        userParam.put("user_id", user_id);
        userParam.put("nick_name", "嘉信立恒管理员");
        userParam.put("user_account", "superadmin");
        userParam.put("gender", "1");
        userParam.put("avatar_name", "head.png");
        userParam.put("email", "zhangsan@163.com");
        userParam.put("link_phone", "13788888888");
        userParam.put("password", "qwerasdf");
        userParam.put("admin_flag", 0);
        userParam.put("sec_level", "4");
        userParam.put("enabled_flag", "1");
        userParam.put("pwd_reset_time", 0);
        userParam.put("valid_date", "2022-1-10 15:22:27");
        userParam.put("expire_date", "2099-12-31 15:22:32");
        userParam.put("data_status", "1");
        userParam.put("create_date", new InitialMethod().getDatetime());
        userParam.put("done_date", new InitialMethod().getDatetime());
        userParam.put("create_op_id", user_id);
        userParam.put("op_id", user_id);
        return userParam;
    }
}
